==> huaweicloudsdkiam-3.0.52-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/mapping_option.py <==
# coding: utf-8

import re
import six





class MappingOption:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'rules': 'list[MappingRules]'
    }

    attribute_map = {
        'rules': 'rules'
    }

    def __init__(self, rules=None):
        """MappingOption - a model defined in huaweicloud sdk"""
        
        

        self._rules = None
        self.discriminator = None

        self.rules = rules

    @property
    def rules(self):
        """Gets the rules of this MappingOption.

        将联邦用户映射为本地用户的规则列表。

        :return: The rules of this MappingOption.
        :rtype: list[MappingRules]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this MappingOption.

        将联邦用户映射为本地用户的规则列表。

        :param rules: The rules of this MappingOption.
        :type: list[MappingRules]
        """
        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MappingOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.54-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/mapping_option.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MappingOption:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'rules': 'list[MappingRules]'
    }

    attribute_map = {
        'rules': 'rules'
    }

    def __init__(self, rules=None):
        """MappingOption - a model defined in huaweicloud sdk"""
        
        

        self._rules = None
        self.discriminator = None

        self.rules = rules

    @property
    def rules(self):
        """Gets the rules of this MappingOption.

        将联邦用户映射为本地用户的规则列表。

        :return: The rules of this MappingOption.
        :rtype: list[MappingRules]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this MappingOption.

        将联邦用户映射为本地用户的规则列表。

        :param rules: The rules of this MappingOption.
        :type: list[MappingRules]
        """
        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MappingOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
